#ifndef NT2_INCLUDE_FUNCTIONS_REM_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_REM_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/rem.hpp>

#endif
